import path from 'node:path';
import { isFile } from '../util/fs.js';
import { relative } from '../util/path.js';
import { OwnershipEngine } from '@snyk/github-codeowners/dist/lib/ownership/index.js';
const mergeTypes = (type) => type === 'exports' || type === 'nsExports' ? 'exports' : type === 'types' || type === 'nsTypes' ? 'types' : type;
export default async ({ report, issues, options }) => {
    let opts = {};
    try {
        opts = options ? JSON.parse(options) : opts;
    }
    catch (error) {
        console.error(error);
    }
    const json = {};
    const codeownersFilePath = path.resolve(opts.codeowners ?? '.github/CODEOWNERS');
    const codeownersEngine = (await isFile(codeownersFilePath)) && OwnershipEngine.FromCodeownersFile(codeownersFilePath);
    const flatten = (issues) => Object.values(issues).map(Object.values).flat();
    const initRow = (filePath) => {
        const file = relative(filePath);
        const row = {
            file,
            ...(codeownersEngine && { owners: codeownersEngine.calcFileOwnership(file) }),
            ...(report.files && { files: false }),
            ...(report.dependencies && { dependencies: [] }),
            ...(report.devDependencies && { devDependencies: [] }),
            ...(report.unlisted && { unlisted: [] }),
            ...((report.exports || report.nsExports) && { exports: [] }),
            ...((report.types || report.nsTypes) && { types: [] }),
            ...(report.duplicates && { duplicates: [] }),
        };
        return row;
    };
    for (const [reportType, isReportType] of Object.entries(report)) {
        if (isReportType) {
            if (reportType === 'files') {
                Array.from(issues[reportType]).forEach(filePath => {
                    json[filePath] = json[filePath] ?? initRow(filePath);
                    json[filePath][reportType] = true;
                });
            }
            else {
                const type = mergeTypes(reportType);
                flatten(issues[reportType]).forEach(({ filePath, symbol }) => {
                    json[filePath] = json[filePath] ?? initRow(filePath);
                    json[filePath][type]?.push(symbol);
                });
            }
        }
    }
    console.log(JSON.stringify(Object.values(json)));
};
