import path from 'node:path';
import { globby } from 'globby';
import { timerify } from './performance.js';
const ensurePosixPath = (value) => value.split(path.sep).join(path.posix.sep);
const prependDirToPattern = (workingDir, pattern) => {
    if (pattern.startsWith('!'))
        return '!' + path.posix.join(workingDir, pattern.slice(1));
    return path.posix.join(workingDir, pattern);
};
const glob = async ({ cwd, workingDir, patterns, ignore, gitignore, }) => {
    const cwdPosix = ensurePosixPath(cwd);
    const workingDirPosix = ensurePosixPath(workingDir);
    return globby(patterns.map(pattern => prependDirToPattern(path.posix.relative(cwdPosix, workingDirPosix), pattern)), {
        cwd,
        ignore: [...ignore, '**/node_modules/**'],
        gitignore,
        absolute: true,
    });
};
export const _glob = timerify(glob);
