import { Project } from 'ts-morph';
import { findDuplicateExportedNames, hasReferencingDefaultImport, findReferencingNamespaceNodes, } from 'ts-morph-helpers';
import { timerify } from './performance.js';
const getExportedDeclarations = (sourceFile) => sourceFile.getExportedDeclarations();
const findReferences = (identifier) => identifier?.findReferences() ?? [];
const createProject = (projectOptions, paths) => {
    const project = new Project(projectOptions);
    if (paths)
        project.addSourceFilesAtPaths(paths);
    return project;
};
const resolveSourceFileDependencies = (project) => project.resolveSourceFileDependencies();
const removeExternalSourceFiles = (project) => project.getSourceFiles().filter(sourceFile => {
    if (/\/node_modules\//.test(sourceFile.getFilePath())) {
        project.removeSourceFile(sourceFile);
        return false;
    }
    return true;
});
export const partitionSourceFiles = (projectFiles, productionFiles) => {
    const productionFilePaths = productionFiles.map(file => file.getFilePath());
    const usedFiles = [];
    const unusedFiles = [];
    projectFiles.forEach(projectFile => {
        if (productionFilePaths.includes(projectFile.getFilePath())) {
            usedFiles.push(projectFile);
        }
        else {
            unusedFiles.push(projectFile);
        }
    });
    return [usedFiles, unusedFiles];
};
export const _createProject = timerify(createProject);
export const _resolveSourceFileDependencies = timerify(resolveSourceFileDependencies);
export const _removeExternalSourceFiles = timerify(removeExternalSourceFiles);
export const _findReferencingNamespaceNodes = timerify(findReferencingNamespaceNodes);
export const _hasReferencingDefaultImport = timerify(hasReferencingDefaultImport);
export const _findDuplicateExportedNames = timerify(findDuplicateExportedNames);
export const _getExportedDeclarations = timerify(getExportedDeclarations);
export const _findReferences = timerify(findReferences);
